package com.example.what_the_fantasy.ui.screens

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.what_the_fantasy.ui.theme.What_The_FantasyTheme

@Composable
fun SignUpPage(navController: NavController) {
    val gradient = Brush.linearGradient(
        colors = listOf(Color(0xFF7B1FA2), Color(0xFF311B92)), // Violet clair → Violet foncé
        start = Offset(0f, 1000f), // Départ en bas à gauche
        end = Offset(1000f, 0f) // Fin en haut à droite
    )

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFF100C1B)),
        contentAlignment = Alignment.Center
    ){
        Column(
            modifier = Modifier
                .fillMaxWidth(0.9f) // Ajuste la largeur
                .padding(20.dp) // Marge extérieure
                .clip(RoundedCornerShape(16.dp)) // Arrondi les angles
                .background(gradient) // Ajoute un fond blanc
                .padding(20.dp), // Padding interne
            horizontalAlignment = Alignment.CenterHorizontally
        ) {

            TitleSign("Inscription", 20,Color.White)
            IdentifiantTextFieldSign("Identifiant*")
            EmailTextFieldSign("Email*")
            PassWdTextFieldSign("Mot de passe*")
            PassWdConfirmTextFieldSign("Confirmer mot de passe*")
            SpaceSign(16)
            ConnexionButtonSign("S'incrire",18, Color.White, Color.Black)
            SpaceSign(16)
            CreateAccountButtonSign("Se connecter",12, Color.White, navController = navController)

        }
    }
}

@Composable
fun SpaceSign(height : Int){
    Spacer(
        modifier = Modifier
            .height(height.dp)) // Ajoute un espacement
}


@Composable
fun IdentifiantTextFieldSign(textIdentifiant : String){
    var identifiant by remember { mutableStateOf("") } // Stocke la valeur du champ
    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = identifiant,
            onValueChange = { identifiant = it },
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Text),
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun EmailTextFieldSign(textIdentifiant : String){
    var identifiant by remember { mutableStateOf("") } // Stocke la valeur du champ
    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = identifiant,
            onValueChange = { identifiant = it },
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Email),
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun PassWdTextFieldSign(textpasswd : String){
    var passwd by remember { mutableStateOf("") } // Stocke la valeur du champ
    var passwordVisible by remember { mutableStateOf(false) } // État pour afficher/masquer
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = passwd,
            onValueChange = { passwd = it },
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = { passwordVisible = !passwordVisible }) {
                }
            },
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun PassWdConfirmTextFieldSign(textpasswd : String){
    var passwd by remember { mutableStateOf("") } // Stocke la valeur du champ
    var passwordVisible by remember { mutableStateOf(false) } // État pour afficher/masquer
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = passwd,
            onValueChange = { passwd = it },
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = { passwordVisible = !passwordVisible }) {
                }
            },
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun TitleSign(title : String, size : Int, color : Color){
    Text(
        text = title,
        fontSize = size.sp,
        fontWeight = FontWeight.Bold,
        color = color
    )
}

@Composable
fun ConnexionButtonSign(title : String, size : Int, colorButton : Color, colorText : Color){
    Button(
        onClick = { /* Action */ },
        colors = ButtonDefaults.buttonColors(containerColor = colorButton),
        modifier = Modifier
            .fillMaxWidth(),
    ) {
        Text(title, fontSize = size.sp, color = colorText)
    }
}

@Composable
fun CreateAccountButtonSign(title: String, size: Int, color: Color, navController: NavController) {
    Text(
        text = title,
        fontSize = size.sp,
        color = color,
        modifier = Modifier.clickable {
            navController.popBackStack() //  Revenir à la page précédente
        }
    )
}
